@@ -4,13 +4,14 @@
 
 from labstep.entities.device.model import Device
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
 def getDevice(user, device_id):
     return entityRepository.getEntity(user, Device, id=device_id)
 
 
-def getDevices(user, count=100, search_query=None, extraParams={}):
+def getDevices(user, count=100, search_query=UNSPECIFIED, extraParams={}):
     params = {"search_query": search_query, **extraParams}
     return entityRepository.getEntities(user, Device, count, params)
 
@@ -20,6 +21,6 @@ def newDevice(user, name, extraParams={}):
     return entityRepository.newEntity(user, Device, params)
 
 
-def editDevice(device, name=None, deleted_at=None, extraParams={}):
+def editDevice(device, name=UNSPECIFIED, deleted_at=UNSPECIFIED, extraParams={}):
     params = {"name": name, "deleted_at": deleted_at, **extraParams}
     return entityRepository.editEntity(device, params)
