@@ -7,7 +7,7 @@ from labstep.constants import UNSPECIFIED
 
 
 class ExperimentTimer(Entity):
-    __entityName__ = "experiment-timer"
+    __entityName__ = "protocol-timer"
     __hasGuid__ = True
 
     def edit(self, hours=UNSPECIFIED, minutes=UNSPECIFIED, seconds=UNSPECIFIED):
