@@ -7,9 +7,10 @@ from labstep.service.config import configService
 from labstep.service.request import requestService
 from labstep.entities.invitation.model import Invitation
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
-def newInvitations(user, invitationType, emails, organization_id, workspace_id=None):
+def newInvitations(user, invitationType, emails, organization_id, workspace_id=UNSPECIFIED):
     url = url_join(configService.getHost(), 'api/generic',
                    'share-link-invitation', invitationType)
     headers = getHeaders(user=user)
@@ -22,5 +23,5 @@ def newInvitations(user, invitationType, emails, organization_id, workspace_id=N
 
 
 def getInvitations(user, organization_id, extraParams):
-    return entityRepository.getEntities(user, Invitation, count=None, filterParams={
+    return entityRepository.getEntities(user, Invitation, count=UNSPECIFIED, filterParams={
         'organization_id': organization_id, **extraParams})
