@@ -4,6 +4,7 @@
 
 from labstep.entities.jupyterInstance.model import JupyterInstance
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
 def getJupyterInstance(user, guid):
@@ -12,10 +13,12 @@ def getJupyterInstance(user, guid):
 
 def editJupyterInstance(
     jupyterInstance,
-    startedAt=None,
-    endedAt=None
+    data=UNSPECIFIED,
+    startedAt=UNSPECIFIED,
+    endedAt=UNSPECIFIED
 ):
     params = {
+        "data": data,
         "started_at": startedAt,
         "ended_at": endedAt,
     }
