@@ -4,7 +4,7 @@
 
 from labstep.generic.entity.model import Entity
 from labstep.service.helpers import handleDate, getTime
-
+from labstep.constants import UNSPECIFIED
 
 TYPE_DEFAULT = "default"
 TYPE_NUMERIC = "numeric"
@@ -71,7 +71,7 @@ class Metadata(Entity):
     __entityName__ = "metadata"
     __searchKey__ = "label"
 
-    def edit(self, fieldName=None, value=None, extraParams={}):
+    def edit(self, fieldName=UNSPECIFIED, value=UNSPECIFIED, extraParams={}):
         """
         Edit the value of an existing Metadata.
 
