@@ -4,6 +4,7 @@
 
 from labstep.generic.entity.model import Entity
 from labstep.constants import UNSPECIFIED
+from labstep.service.helpers import getTime
 
 
 class Molecule(Entity):
@@ -37,3 +38,18 @@ class Molecule(Entity):
             **extraParams
         }
         return entityRepository.editEntity(self, params)
+
+    def delete(self):
+        """
+        Delete an existing Molecule.
+
+        Example
+        -------
+        ::
+
+            my_molecule = user.getMolecule(17000)
+            my_molecule.delete()
+        """
+        import labstep.entities.molecule.repository as moleculeRepository
+
+        return moleculeRepository.editMolecule(self, deleted_at=getTime())
