@@ -4,6 +4,7 @@
 
 from labstep.entities.resourceCategory.model import ResourceCategory
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
 def getResourceCategory(user, resourceCategory_id):
@@ -27,7 +28,7 @@ def getResourceCategory(user, resourceCategory_id):
 
 
 def getResourceCategorys(
-        user, count=100, search_query=None, tag_id=None, extraParams={}
+        user, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}
 ):
     """
     Retrieve a list of a user's ResourceCategorys on Labstep,
@@ -77,7 +78,7 @@ def newResourceCategory(user, name, extraParams={}):
 
 
 def editResourceCategory(
-        resourceCategory, name=None, deleted_at=None, extraParams={}
+        resourceCategory, name=UNSPECIFIED, deleted_at=UNSPECIFIED, extraParams={}
 ):
     params = {"name": name, "deleted_at": deleted_at, **extraParams}
     return entityRepository.editEntity(resourceCategory, params)
