@@ -4,6 +4,7 @@
 
 from labstep.entities.resourceLocation.model import ResourceLocation
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
 def getResourceLocation(user, resource_location_id):
@@ -13,18 +14,17 @@ def getResourceLocation(user, resource_location_id):
 
 
 def getResourceLocations(
-    user, count=100, search_query=None, tag_id=None, extraParams={}
+    user, count=100, search_query=UNSPECIFIED, extraParams={}
 ):
     params = {
         "group_id": user.activeWorkspace,
         "search_query": search_query,
-        "tag_id": tag_id,
         **extraParams,
     }
     return entityRepository.getEntities(user, ResourceLocation, count, params)
 
 
-def newResourceLocation(user, name, outer_location_id=None, extraParams={}):
+def newResourceLocation(user, name, outer_location_id=UNSPECIFIED, extraParams={}):
     params = {"name": name, "outer_location_id": outer_location_id, **extraParams}
     return entityRepository.newEntity(user, ResourceLocation, params)
 
