@@ -7,6 +7,7 @@ from labstep.generic.entity.model import Entity
 from labstep.entities.workspaceMember.model import WorkspaceMember
 from labstep.entities.sharelink.model import Sharelink
 from labstep.service.helpers import getTime
+from labstep.constants import UNSPECIFIED
 
 
 class Workspace(Entity):
@@ -25,7 +26,7 @@ class Workspace(Entity):
 
     __entityName__ = "group"
 
-    def edit(self, name=None, extraParams={}):
+    def edit(self, name=UNSPECIFIED, extraParams={}):
         """
         Edit an existing Workspace.
 
@@ -69,11 +70,11 @@ class Workspace(Entity):
     def getExperiments(
         self,
         count=100,
-        search_query=None,
-        created_at_from=None,
-        created_at_to=None,
-        tag_id=None,
-        collection_id=None,
+        search_query=UNSPECIFIED,
+        created_at_from=UNSPECIFIED,
+        created_at_to=UNSPECIFIED,
+        tag_id=UNSPECIFIED,
+        collection_id=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -129,11 +130,11 @@ class Workspace(Entity):
     def getProtocols(
         self,
         count=100,
-        search_query=None,
-        created_at_from=None,
-        created_at_to=None,
-        tag_id=None,
-        collection_id=None,
+        search_query=UNSPECIFIED,
+        created_at_from=UNSPECIFIED,
+        created_at_to=UNSPECIFIED,
+        tag_id=UNSPECIFIED,
+        collection_id=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -186,7 +187,7 @@ class Workspace(Entity):
             extraParams=extraParams,
         )
 
-    def getResources(self, count=100, search_query=None, tag_id=None, extraParams={}):
+    def getResources(self, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of Resources within this specific Workspace,
         which can be filtered using the parameters:
@@ -221,7 +222,7 @@ class Workspace(Entity):
         )
 
     def getResourceCategorys(
-        self, count=100, search_query=None, tag_id=None, extraParams={}
+        self, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}
     ):
         """
         Retrieve a list of Resource Categories within this specific Workspace,
@@ -256,7 +257,7 @@ class Workspace(Entity):
             self.__user__, count, search_query, tag_id, extraParams=extraParams
         )
 
-    def getResourceLocations(self, count=100, search_query=None, extraParams={}):
+    def getResourceLocations(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of Resource Locations within this specific Workspace,
         which can be filtered using the parameters:
@@ -288,7 +289,7 @@ class Workspace(Entity):
             self.__user__, count, search_query, extraParams=extraParams
         )
 
-    def getResourceItems(self, count=100, search_query=None, extraParams={}):
+    def getResourceItems(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of ResourceItems in a workspace on Labstep.
 
@@ -318,7 +319,7 @@ class Workspace(Entity):
         )
 
     def getOrderRequests(
-        self, count=100, name=None, status=None, tag_id=None, extraParams={}
+        self, count=100, name=UNSPECIFIED, status=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}
     ):
         """
         Retrieve a list of Order Requests within this specific Workspace,
@@ -356,7 +357,7 @@ class Workspace(Entity):
             extraParams=extraParams,
         )
 
-    def getTags(self, count=1000, search_query=None, type=None, extraParams={}):
+    def getTags(self, count=1000, search_query=UNSPECIFIED, type=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of Tags within this specific Workspace,
         which can be filtered using the parameters:
@@ -416,7 +417,7 @@ class Workspace(Entity):
         import labstep.entities.workspaceMember.repository as workspaceMemberRepository
         return workspaceMemberRepository.addMember(self.__user__, workspace_id=self.id, user_id=user_id)
 
-    def getMembers(self, count=100, search_query=None, extraParams={}):
+    def getMembers(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of the members of the workspace.
 
@@ -442,7 +443,7 @@ class Workspace(Entity):
         import labstep.entities.workspaceMember.repository as workspaceMemberRepository
         return workspaceMemberRepository.getMembers(self.__user__, workspace_id=self.id, search_query=search_query, extraParams=extraParams)
 
-    def getFiles(self, count=100, search_query=None, file_type=None, extraParams={}):
+    def getFiles(self, count=100, search_query=UNSPECIFIED, file_type=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of Files in the Workspace on Labstep,
         which can be filtered using the parameters:
@@ -477,7 +478,7 @@ class Workspace(Entity):
             self.__user__, count, search_query, file_type, extraParams=extraParams
         )
 
-    def getDevices(self, count=100, search_query=None, extraParams={}):
+    def getDevices(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of Devices within this specific Workspace,
         which can be filtered using the parameters:
@@ -548,7 +549,7 @@ class Workspace(Entity):
         return shareLinkRepository.getSharelink(self)
 
     def getCollections(
-        self, count=1000, search_query=None, type="experiment", extraParams={}
+        self, count=1000, search_query=UNSPECIFIED, type="experiment", extraParams={}
     ):
         """
         Retrieve a list of Collections within this specific Workspace,
@@ -619,7 +620,7 @@ class Workspace(Entity):
         return entityRepository.editEntity(member, {"is_home": True})
 
     def setAutosharing(
-        self, experiment_sharing=None, protocol_sharing=None, resource_sharing=None
+        self, experiment_sharing=UNSPECIFIED, protocol_sharing=UNSPECIFIED, resource_sharing=UNSPECIFIED
     ):
         """
         Parameters
