@@ -140,9 +140,10 @@ def exportEntity(entity, rootPath, folderName=UNSPECIFIED):
     from labstep.entities.file.model import File
 
     if folderName is UNSPECIFIED:
-        if entityNameInFolderName:
-            folderName = f'{entity.id} - {entity.name}' if hasattr(
-                entity, 'name') else f'{entity.id}'
+        if entityNameInFolderName and hasattr(
+                entity, 'name'):
+            santitisedName = entity.name.replace('/', ' ').replace('\\', ' ')
+            folderName = f"{entity.id} - {santitisedName}"
         else:
             folderName = str(entity.id)
 
