@@ -14,6 +14,6 @@ class EntityList(list):
             return hits[0]
 
         if len(hits) > 1:
-            print('Warning: multiple matches found')
+            print(f'Warning: multiple matches found for "{key}"')
 
             return hits[0]
