@@ -3,6 +3,7 @@
 # Author: Barney Walker <barney@labstep.com>
 
 from labstep.service.request import requestService
+import base64
 
 
 def htmlToPDF(authenticatedUser, html):
@@ -25,4 +26,4 @@ def htmlToPDF(authenticatedUser, html):
     url = "https://pdf-generator.labstep.com"
     response = requestService.post(url, json=body, headers=headers)
 
-    return response.content
+    return base64.b64decode(response.content)
